@@ -10,8 +10,6 @@ CDN_URL = 'https://cdn.filestackcontent.com'
 PROCESS_URL = 'https://process.filestackapi.com'
 
 MULTIPART_START_URL = 'https://upload.filestackapi.com/multipart/start'
-MULTIPART_UPLOAD_URL = 'https://upload.filestackapi.com/multipart/upload'
-MULTIPART_COMPLETE_URL = 'https://upload.filestackapi.com/multipart/complete'
 
 HEADERS = {
     'User-Agent': 'filestack-python {}'.format(__version__),
@@ -19,6 +17,7 @@ HEADERS = {
 }
 
 DEFAULT_CHUNK_SIZE = 5 * 1024 ** 2
+DEFAULT_UPLOAD_MIMETYPE = 'application/octet-stream'
 
 STORE_PATH = 'store'
 FILE_PATH = 'file'
